-- 1) For every customer occupation, customer gender  and product brand 
-- compute the total cost and the ratio
-- between that total cost and the total sales in the occupation

select p.brand_name, c.gender, c.occupation, sum(s.store_cost) as CostTot,
         sum(store_cost)/sum(sum(store_sales)) 
		 over (partition by c.occupation) as ratio
from sales_fact s join product p on s.product_id = p.product_id
       join customer c on s.customer_id = c.customer_id 
group by p.brand_name, c.gender, c.occupation
order by p.brand_name, c.gender, c.occupation, ratio desc

--2) For every customer occupation, product department, return the top stores 
-- having a ratio_per greater than 1% where the ratio_per is the percentage 
--of sales over the total sales of all products. Result must be ordered 
-- by percentage descending.

with rk as 
(select c.occupation, pc.product_department, s.store_id, 
sum(store_sales)/sum(sum(store_sales)) 
over (partition by c.occupation) as ratio
from sales_fact s join product p on s.product_id = p.product_id
       join customer c on s.customer_id = c.customer_id join product_class pc 
	   on pc.product_class_id=p.product_class_id
group by occupation, product_department, store_id)
select occupation, product_department, store_id, ratio
from rk 
where ratio > 0.01
order by ratio desc


--3) For every product category and customer country, return the store with  
-- highest ratio between the profit over the total profit in that country. 
-- Result must be ordered  by percentage descending.

with rk as 
(select c.country, pc.product_category, s.store_id,
sum(store_sales-store_cost)/sum(sum(store_sales-store_cost)) 
over (partition by c.country) as ratio,
rank() over (partition by c.country, pc.product_category order by sum(store_sales-store_cost) desc) as rk

from sales_fact s join product p on s.product_id = p.product_id
       join customer c on s.customer_id = c.customer_id join product_class pc 
	   on pc.product_class_id=p.product_class_id
group by c.country, pc.product_category, store_id)

select country, product_category, store_id, ratio
from rk 
where rk=1
order by ratio desc